@@ -2,7 +2,7 @@ import nib.yaml as yaml
 from nib.config import Config
 from nib.document import Document
 from nib.resource import Resource
-from nib.render import Render
+from nib.render import Render, jinja
 from nib.processor import Processor
 from nib.processor import before, after, document, resource, markup
 from nib.build import Build
